@@ -21,14 +21,22 @@ fi
 # get requested format
 cdonoff='off'
 dvdonoff='off'
+none='off'
 case $format in
 	CD) cdonoff='on' ;;
 	DVD) dvdonoff='on' ;;
+	NONE) none='on' ;;
 esac
 
 format=`Xdialog --title "Optical disc archiving" --stdout --no-tags --separator ' ' \
-                --radiolist  "Format allowed for archiving:" 0 0 3 \
-                'CD' 'CD' $cdonoff  'DVD' 'DVD' $dvdonoff` || exit
+                --radiolist  "Format allowed for archiving:" 0 0 4 \
+                'CD' 'CD' $cdonoff  'DVD' 'DVD' $dvdonoff 'NONE' 'NONE' $none` || exit
+
+if [ $format == 'NONE' ] ;
+then
+  rm /etc/wodim.conf
+  exit
+fi
 
 # get no. of writers
 copies=`Xdialog --stdout --title "Optical disc archiving" \
